<?php
/*
Plugin Name: CF7 WooCommerce Products Dropdown (EasyToolsWP)
Description: Adds a dropdown with WooCommerce products to Contact Form 7. [woocommerce_products_dropdown your-field-name]
Version: 2.0
Author: EasyToolsWP.com
*/

// Hook to initialize the plugin
add_action('plugins_loaded', 'cf7_wc_products_plugin_init');

function cf7_wc_products_plugin_init() {
    // Check if WooCommerce and Contact Form 7 are active
    if (!class_exists('WooCommerce') || !class_exists('WPCF7')) {
        add_action('admin_notices', 'cf7_wc_products_plugin_notice');
        add_action('admin_init', 'cf7_wc_products_plugin_deactivate');
        return;
    }
    
    // Initialize the custom form tag
    add_action('wpcf7_init', 'cf7_add_woocommerce_products_dropdown');
    // Add mailtag support
    add_filter('wpcf7_mail_tag_replacement', 'cf7_wc_products_mail_tag_replacement', 10, 4);
    // Add tag generator for Contact Form 7
    add_action('wpcf7_admin_init', 'cf7_wc_products_add_tag_generator');
    // Add mail tag examples to mail panel
    add_filter('wpcf7_editor_panels', 'cf7_wc_products_add_mail_tag_example');
}

function cf7_wc_products_plugin_notice() {
    echo '<div class="notice notice-error is-dismissible">';
    echo '<p><strong>CF7 WooCommerce Products Dropdown (EasyToolsWP)</strong> requires both WooCommerce and Contact Form 7 to be installed and active.</p>';
    echo '</div>';
}

function cf7_wc_products_plugin_deactivate() {
    deactivate_plugins(plugin_basename(__FILE__));
}

function cf7_add_woocommerce_products_dropdown() {
    wpcf7_add_form_tag('woocommerce_products_dropdown', 'cf7_woocommerce_products_dropdown_handler', true);
}

function cf7_woocommerce_products_dropdown_handler($tag) {
    $args = array(
        'post_type' => 'product',
        'posts_per_page' => -1,
        'post_status' => 'publish',
        'tax_query' => array(
            array(
                'taxonomy' => 'product_visibility',
                'field'    => 'name',
                'terms'    => 'exclude-from-catalog',
                'operator' => 'NOT IN',
            ),
        ),
    );

    $products = get_posts($args);

    $html = '<span class="wpcf7-form-control-wrap ' . sanitize_html_class($tag->name) . '">';
    $html .= '<select name="' . esc_attr($tag->name) . '" class="wpcf7-form-control wpcf7-select" id="' . esc_attr($tag->name) . '">';
    $html .= '<option value="Other subject">Other subject</option>';

    foreach ($products as $product) {
        $html .= '<option value="' . esc_attr($product->post_title) . '">' . esc_html($product->post_title) . '</option>';
    }

    $html .= '</select></span>';

    return $html;
}

function cf7_wc_products_add_tag_generator() {
    if (class_exists('WPCF7_TagGenerator')) {
        $tag_generator = WPCF7_TagGenerator::get_instance();
        $tag_generator->add('woocommerce_products_dropdown', __('WooCommerce Products Dropdown', 'contact-form-7'), 'cf7_wc_products_tag_generator_menu');
    }
}

function cf7_wc_products_tag_generator_menu($contact_form, $args = '') {
    ?>
    <div class="control-box">
        <fieldset>
            <legend><?php _e('Generates a dropdown menu with WooCommerce products for Contact Form 7.', 'contact-form-7'); ?></legend>
            <table class="form-table">
                <tbody>
                    <tr>
                        <th scope="row"><?php _e('Name', 'contact-form-7'); ?></th>
                        <td>
                            <input type="text" name="name" class="tg-name oneline" />
                        </td>
                    </tr>
                </tbody>
            </table>
        </fieldset>
    </div>
    <div class="insert-box">
        <input type="text" name="woocommerce_products_dropdown" class="tag code" readonly="readonly" onfocus="this.select()" />
        <div class="submitbox">
            <input type="button" class="button button-primary insert-tag" value="<?php _e('Insert Tag', 'contact-form-7'); ?>" />
        </div>
    </div>
    <?php
}

function cf7_wc_products_add_mail_tag_example($panels) {
    if (!isset($panels['mail'])) {
        return $panels;
    }

    // Get all WooCommerce Products Dropdown fields from the form
    $form_tags = wpcf7_scan_form_tags();

    // Collect all WooCommerce Products Dropdown field names
    $dropdown_fields = array();
    foreach ($form_tags as $tag) {
        if ($tag['type'] === 'woocommerce_products_dropdown') {
            $dropdown_fields[] = $tag['name'];
        }
    }

    if (!empty($dropdown_fields)) {
        // Add a custom callback to display WooCommerce Products Dropdown mail tags example
        $panels['mail']['callback'] = function($post) use ($panels, $dropdown_fields) {
            echo '<h2>' . __('WooCommerce Products Dropdown Mail Tag Examples', 'contact-form-7') . '</h2>';
            echo '<p>' . __('To include the selected WooCommerce product in your email, use the following mail tags:', 'contact-form-7') . '</p>';
            echo '<ul>';
            foreach ($dropdown_fields as $field_name) {
                echo '<li><code>[' . esc_html($field_name) . ']</code></li>';
            }
            echo '</ul>';
            wpcf7_admin_mail_panel($post);
        };
    }

    return $panels;
}

function cf7_wc_products_mail_tag_replacement($replaced, $submitted, $html, $mail_tag) {
    if (strpos($mail_tag, 'woocommerce_products_dropdown') === 0) {
        $field_name = trim(str_replace('woocommerce_products_dropdown ', '', $mail_tag));
        $replaced = isset($submitted[$field_name]) ? $submitted[$field_name] : '';
    }

    return $replaced;
}
?>